@@ -1,3 +1,6 @@
+import re
+
+
 def find_expression(key, value, settings, *args):
     """Create an expression which can be used as a value for Expression.find_expression"""
     from routeros_diff.arguments import ArgList, Arg
@@ -36,3 +39,16 @@ def quote(s: str):
         return f'"{s}"'
     else:
         return s
+
+
+def unescape_string(s: str):
+    """Remove '\' escapes from a string value"""
+
+    # Remove escaped new lines where the new line starts with a \_
+    # (\_ should be interpreted as space)
+    s = re.sub(r" *\\\n *\\_", " ", s)
+
+    # Escapes without an '_' should simply be removed
+    s = re.sub(r" *\\\n *", "", s)
+
+    return s
